@@ -99,7 +99,9 @@ pub enum CompositeOperation {
 // https://html.spec.whatwg.org/#canvasfillrule
 #[derive(Debug, Copy, Clone, PartialEq, Eq)]
 pub enum FillRule {
+    /// [Non-zero winding rule](https://en.wikipedia.org/wiki/Nonzero-rule)
     NonZero,
+    /// [Even-odd winding rule](https://en.wikipedia.org/wiki/Even%E2%80%93odd_rule)
     EvenOdd
 }
 
@@ -287,7 +289,7 @@ impl CanvasRenderingContext2d {
     // https://html.spec.whatwg.org/#2dcontext:dom-context-2d-canvas
     pub fn get_canvas(&self) -> CanvasElement {
         js! (
-            @{&self.0}.canvas;
+            return @{&self.0}.canvas;
         ).try_into().unwrap()
     }
 
